@@ -20,7 +20,7 @@ class RRCache(Cache):
 
     def __init__(self, maxsize, choice=random.choice, missing=None,
                  getsizeof=None):
-        Cache.__init__(self, maxsize, missing=missing, getsizeof=getsizeof)
+        Cache.__init__(self, maxsize, missing, getsizeof)
         self.__choice = choice
 
     def popitem(self):
